/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../attributes.h"

class String : public Linkable {

	private:
	
		int capacity;
		char *text;

	public:

	String();
	~String();
	
	void reallocate(int size);

	void operator= (const char *c);
	bool operator== (const char *c);
	bool operator!= (const char *c);
	
	void operator= (String s) GCC_NORETURN;
	void operator= (String *s) GCC_NORETURN;
	
	void setText(const char *text, ...) GCC_PRINTF(2, 3);
	const char *getText();
	
	void toLowerCase();
	void captialise();
	
	void trim();

};
